@@ -4,6 +4,42 @@ from cururo.util.publisher import Publisher
 from github import Github, Auth, GithubException
 from github.Issue import Issue
 
+class MermaidPrivate:
+    def __init__(self, pattern=r'```mermaid\n(.*?)\n```', types='journey'):
+        self.pattern=pattern
+        self.types=types
+
+    def generate_journey(self, title, to_add:str, body=''):
+        code, exists = self.get_mermaid_code(title, body)
+        code = self.append2mermaid(code, to_add)
+        return self.insert_code(body, code, exists)
+
+    def journey(self, title):
+        return f'  journey\n    title {title}'
+
+    def insert_code(self, body: str, mermaid_code: str, replace=True) -> str:
+        if replace:
+            # Replace existing Mermaid code
+            return re.sub(self.pattern, f'```mermaid\n{mermaid_code}\n```', body, flags=re.DOTALL)
+        else:
+            # Append Mermaid code at the end if pattern doesn't exist
+            return body + f'\n```mermaid\n{mermaid_code}\n```'
+
+    def get_mermaid_code(self, title: str, body: str):
+        match = re.search(self.pattern, body, re.DOTALL)
+        if match:
+            return match.group(1), True
+        return self.journey(title), False
+
+    def dict2section(self, section: str, steps: Dict[str, str], who: str) -> str:
+        section_str = f'    section {section}\n'
+        for step, value in steps.items():
+            section_str += f'      {step}: {value}: {who}\n'
+        return section_str
+    
+    def append2mermaid(self, mermaid: str, data: str) -> str:
+        return f'{mermaid}\n{data}'
+
 class GitIssuePublisher(Publisher):
     """
     A class to publish and manage GitHub issues with branch-specific threading and graph updates.
@@ -54,9 +90,10 @@ class GitIssuePublisher(Publisher):
             print(1)
             existing_issue = self.get_thread(title)
 
-            # main_comment = existing_issue.get_comments()[0]
             print(2)
-            updated_body = self.append_data_to_comment(existing_issue.body or '', data['message']['adherence'])
+            updated_body = self.generate_issue(existing_issue.body or '', 
+                                                        message=data['message']['adherence']['score'],
+                                                        vulnerability=data['codeVulnerability']['score'])
             print(3)
             existing_issue.edit(body=updated_body)
             print(4)
@@ -124,7 +161,7 @@ class GitIssuePublisher(Publisher):
 
         return '\n'.join(report)
 
-    def append_data_to_comment(self, existing_body: str, adherence: Dict[str, Any]) -> str:
+    def generate_issue(self, existing_body: str, **scores) -> str:
         """
         Appends adherence data to the existing comment body using a Mermaid XY diagram.
 
@@ -132,56 +169,11 @@ class GitIssuePublisher(Publisher):
         :param adherence: A dictionary with adherence score details.
         :return: The updated comment body.
         """
-        # Extract existing data points from the comment
-        data_points = self.extract_data_points(existing_body)
-        data_points.append((self.sha, adherence['score']))
+        mermaid = MermaidPrivate()
+        data = mermaid.dict2section(self.sha, scores, self.user)
+        return mermaid.generate_journey("#Scores History", data, existing_body)
 
-        # Generate the new Mermaid diagram
-        mermaid_diagram = self.generate_mermaid_diagram(data_points)
-
-        # Update the comment with the new diagram
-        updated_body = existing_body.split("\n**Adherence Scores History:**")[0]
-        updated_body += "\n**Adherence Scores History:**\n" + mermaid_diagram
-        return updated_body
-
-    def generate_mermaid_diagram(self, data_points: List[tuple]) -> str:
-        """
-        Generates a Mermaid diagram using data points.
-
-        :param data_points: A list of tuples containing commit SHAs and scores.
-        :return: A string representing the Mermaid diagram.
-        """
-        diagram = ['```mermaid', 'graph TD']
-        for sha, score in data_points:
-            diagram.append(f"A({sha[:7]}) -- {score} --> B({score})")
-        diagram.append('```')
-        return '\n'.join(diagram)
-
-    def extract_data_points(self, body: str) -> List[tuple]:
-        """
-        Extracts data points from the Mermaid diagram in the comment body.
-
-        :param body: The comment body.
-        :return: A list of tuples with commit SHAs and scores.
-        """
-        lines = body.split("\n")
-        data_points = []
-        parsing = False
-        for line in lines:
-            if 'graph TD' in line:
-                parsing = True
-                continue
-            if parsing:
-                if line.startswith('```'):
-                    break
-                parts = line.split('--')
-                if len(parts) == 2:
-                    sha = parts[0].strip('A()')
-                    score = parts[1].split(' --> B')[0].strip()
-                    data_points.append((sha, int(score)))
-        return data_points
     
-
 class WebPublisher(Publisher):
 
     def __init__(self, url:str, secret:str):
